import * as React from "react";
import Switch from "./Switch";
import { shallow } from 'enzyme';
describe('Switch', () => {
    it('renders nothing by default', () => {
        const component = shallow(React.createElement(Switch, null));
        expect(component.html()).toMatch('');
    });
    const C1 = (props) => React.createElement("div", null, "C1");
    const C2 = (props) => React.createElement("div", null, "C2");
    it('renders all hidden when none is selected', () => {
        const component = shallow(React.createElement(Switch, { views: [React.createElement(C1, null), React.createElement(C2, null)] }));
        expect(component.html()).toEqual('<div style="display:none"><div>C1</div></div><div style="display:none"><div>C2</div></div>');
    });
    it('shows first when first is selected without array', () => {
        const component = shallow(React.createElement(Switch, { views: [React.createElement(C1, null), React.createElement(C2, null)], selected: 0 }));
        expect(component.html()).toEqual('<div style="display:contents"><div>C1</div></div><div style="display:none"><div>C2</div></div>');
    });
    it('shows multiple when multiple are selected', () => {
        const component = shallow(React.createElement(Switch, { views: [React.createElement(C1, null), React.createElement(C2, null)], selected: [0, 1] }));
        expect(component.html()).toEqual('<div style="display:contents"><div>C1</div></div><div style="display:contents"><div>C2</div></div>');
    });
    it("doesn't crash when an index is out of bounds", () => {
        const component = shallow(React.createElement(Switch, { views: [React.createElement(C1, null), React.createElement(C2, null)], selected: [0, 1, 2] }));
        expect(component.html()).toEqual('<div style="display:contents"><div>C1</div></div><div style="display:contents"><div>C2</div></div>');
    });
    it('works using children', () => {
        const component = shallow(React.createElement(Switch, { selected: [1] },
            React.createElement(C1, null),
            React.createElement(C2, null)));
        expect(component.html()).toEqual('<div style="display:none"><div>C1</div></div><div style="display:contents"><div>C2</div></div>');
    });
});
//# sourceMappingURL=Switch.test.js.map