"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const renderer = __importStar(require("react-test-renderer"));
const React = __importStar(require("react"));
const namespaces_1 = require("./namespaces");
const useNamespace_1 = require("./useNamespace");
describe('namespaces', function () {
    it('one level namespace', function () {
        renderer.create(React.createElement(namespaces_1.Namespace, { name: 'level1' },
            React.createElement("div", null,
                React.createElement(namespaces_1.Namespace, null, (level) => {
                    expect(level).toEqual(['level1']);
                    return null;
                }))));
    });
    it('two level namespace', function () {
        renderer.create(React.createElement(namespaces_1.Namespace, { name: 'level1' },
            React.createElement("div", null,
                React.createElement(namespaces_1.Namespace, { name: 'level2' },
                    React.createElement("div", null,
                        React.createElement(namespaces_1.Namespace, null, (level) => {
                            expect(level).toEqual(['level1', 'level2']);
                            return null;
                        }))))));
    });
    it('absolute path', function () {
        renderer.create(React.createElement(namespaces_1.Namespace, { name: 'level1' },
            React.createElement("div", null,
                React.createElement(namespaces_1.Namespace, { name: '/level2' },
                    React.createElement("div", null,
                        React.createElement(namespaces_1.Namespace, null, (level) => {
                            expect(level).toEqual(['level2']);
                            return null;
                        }))))));
    });
    it('top level absolute path', function () {
        renderer.create(React.createElement(namespaces_1.Namespace, { name: '/level1' },
            React.createElement("div", null,
                React.createElement(namespaces_1.Namespace, { name: 'level2' },
                    React.createElement("div", null,
                        React.createElement(namespaces_1.Namespace, null, (level) => {
                            expect(level).toEqual(['level1', 'level2']);
                            return null;
                        }))))));
    });
    it('top level absolute path alone', function () {
        renderer.create(React.createElement(namespaces_1.Namespace, { name: '/level1' },
            React.createElement(namespaces_1.Namespace, null, (level) => {
                expect(level).toEqual(['level1']);
                return null;
            })));
    });
    it('relative path', function () {
        renderer.create(React.createElement(namespaces_1.Namespace, { name: 'level1' },
            React.createElement(namespaces_1.Namespace, { name: 'level2' },
                React.createElement(namespaces_1.Namespace, { name: '../level3' },
                    React.createElement(namespaces_1.Namespace, null, (level) => {
                        expect(level).toEqual(['level1', 'level3']);
                        return null;
                    })),
                React.createElement(namespaces_1.Namespace, { name: '../../level3' },
                    React.createElement(namespaces_1.Namespace, null, (level) => {
                        expect(level).toEqual(['level3']);
                        return null;
                    })))));
    });
    it('one level namespace using hooks', function () {
        const ComponentUsingNsHook = () => {
            const level = useNamespace_1.useNamespace();
            expect(level).toEqual(['level1']);
            return null;
        };
        renderer.create(React.createElement(namespaces_1.Namespace, { name: 'level1' },
            React.createElement("div", null,
                React.createElement(ComponentUsingNsHook, null))));
    });
    it('one level namespace using HOC', function () {
        const ComponentToWrap = (props) => {
            const level = props.namespace;
            expect(level).toEqual(['level1']);
            expect(props.name).toEqual('name1');
            return null;
        };
        const WrappedComponent = namespaces_1.withNamespace(ComponentToWrap);
        renderer.create(React.createElement(namespaces_1.Namespace, { name: 'level1' },
            React.createElement("div", null,
                React.createElement(WrappedComponent, { name: 'name1' }))));
    });
    it('one level namespace using class HOC', function () {
        const ComponentToWrap = (props) => {
            const level = props.namespace;
            expect(level).toEqual(['level1']);
            expect(props.name).toEqual('name1');
            return null;
        };
        const WrappedComponent = namespaces_1.withNamespaceClass(ComponentToWrap);
        renderer.create(React.createElement(namespaces_1.Namespace, { name: 'level1' },
            React.createElement("div", null,
                React.createElement(WrappedComponent, { name: 'name1' }))));
    });
});
//# sourceMappingURL=namespaces.test.js.map